Date: 03 23, 2002 4:44:23 AM

# merger

## Purpose

Perform a single tier reduction that dissolves each top level node in the matched range.

## Syntax

merger(number1, number2)

number1 - type: int
number2 - type: int

## Returns

## Remarks

## Example

# Remove the two _adjs nodes
# from the parse tree, merging
# their children under a new
# _adjs node.
@POST
merger(1,2);
@RULES
_adjs <- _adjs _adjs _xyz @@

## See Also

merge, group, excise, splice, POST Actions